<?xml version="1.0"?>
<schema xmlns="http://www.ascc.net/xml/schematron">
	<title>EML-UK 310-Voter Registration</title>
	<ns prefix="eml" uri="urn:oasis:names:tc:evs:schema:eml"/>
	<ns prefix="apd" uri="http://www.govtalk.gov.uk/people/AddressAndPersonalDetails"/>
	<ns prefix="bs7666" uri="http://www.govtalk.gov.uk/people/bs7666-CORE"/>

	<pattern name="eml">
		<rule context="eml:AuditInformation/eml:ProcessingUnits">
			<assert id="3000-001" test="*[@Role='sender']">If there are processing units in the AuditInformation, one must have the role of sender</assert>
			<assert id="3000-002" test="*[@Role='receiver']">If there are processing units in the AuditInformation, one must have the role of receiver</assert>
		</rule>
		<rule context="eml:EML">
			<report id="3000-003" test="eml:SequenceNumber or eml:NumberInSequence or eml:SequencedElementName">This message must not contain the elements used for splitting</report>
			<assert id="3000-004" test="@Id='310'">The value of the Id attribute of the EML element is incorrect</assert>
			<assert id="3000-005" test="eml:VoterRegistration">The message type must match the Id attribute of the EML element</assert>
		</rule>
	</pattern>
	
	<pattern name="eml-ukcore">
		<rule context="eml:EML">
			<assert id="4000-001" test="eml:Seal">A Seal must be present</assert>
			<assert id="4000-102" test="eml:RequestedResponseLanguage">This message must indicate the language for the response</assert>
		</rule>
		<rule context="eml:OtherSeal">
			<assert id="4000-003" test="@Type='RFC2630' or @Type='RFC3161'">If a seal is of type OtherSeal, the Type attribute must have a value of RFC2630 or RFC3161</assert>
		</rule>
		<rule context="eml:Contact">
			<assert id="4000-004" test="*">There must be at least one child of a Contact element</assert>
		</rule>
		<rule context="eml:VoterContact">
			<assert id="4000-005" test="*">There must be at least one child of a VoterContact element</assert>
		</rule>
	</pattern>
	
	<pattern name="eml-310">
		<rule context="eml:Proxy">
			<report id="3310-001" test="eml:VToken or eml:VTokenQualified">The Proxy must not have a VToken or VTokenQualified</report>
		</rule>
	</pattern>

	<pattern name="eml-310-ukcore">
		<rule context="eml:VoterIdentification">
			<assert id="4310-003" test="eml:VoterName">VoterName is mandatory</assert>
			<assert id="4310-004" test="eml:ElectoralAddress">ElectoralAddress is mandatory</assert>
		</rule>
		<rule context="eml:Voter">
			<report id="4310-101" test="eml:VoterInformation/eml:Affiliation">Affiliation is not used</report>
			<report id="4310-102" test="eml:VoterInformation/eml:PlaceOfBirth">PlaceOfBirth is not used</report>
			<report id="4310-103" test="eml:VoterInformation/eml:Eligibility">Eligibility is not used</report>
			<report id="4310-104" test="eml:VoterInformation/eml:Gender">Gender is not used</report>
			<report id="4310-105" test="eml:VoterInformation/eml:Nationality">Nationality is not used</report>
			<report id="4310-106" test="eml:VoterInformation/eml:Ethnicity">Ethnicity is not used</report>
		</rule>
		<rule context="eml:Qualifier">
			<report id="4310-107" test="not(.='A'  or .='L' or .='U' or .='F' or .='E' or .='G' or .='K' or .='Y' or .='OE' or .='overseas')">The eml:Qualifier may only have the values "A", "L", "U", "F", "E", "G", "K", "Y", "OE", or "overseas"</report>
		</rule>
		<rule context="eml:VoterInformation">
			<report id="4310-108" test="(eml:Qualifier='L' and (eml:Qualifier='U' or eml:Qualifier='F' or eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' )) or 
																	(eml:Qualifier='U' and (eml:Qualifier='F' or eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='F' and (eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='E' and (eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='G' and eml:Qualifier='K' )">The Qualifiers "L", "U", "F", "E", "G" and "K" are mutually exclusive</report>
			<report id="4310-109" test="eml:Qualifier='Y' and (eml:Qualifier='L' or eml:Qualifier='U' or eml:Qualifier='F' or eml:Qualifier='E')">The Qualifier "Y" must not appear with the Qualifier "L", "U", "F" or "E"</report>
			<report id="4310-110" test="eml:Qualifier='Y' and not(eml:Qualifier='G' or eml:Qualifier='K')">The Qualifier "Y" must appear with the Qualifier "G" or "K"</report>
		</rule>
	</pattern>
</schema>
