<?xml version="1.0"?>
<schema xmlns="http://www.ascc.net/xml/schematron">
	<title>EML-UK 330-Election List</title>
	<ns prefix="eml" uri="urn:oasis:names:tc:evs:schema:eml"/>
	<ns prefix="apd" uri="http://www.govtalk.gov.uk/people/AddressAndPersonalDetails"/>
	<ns prefix="bs7666" uri="http://www.govtalk.gov.uk/people/bs7666-CORE"/>
	
	<pattern name="eml">
		<rule context="eml:AuditInformation/eml:ProcessingUnits">
			<assert id="3000-001" test="*[@Role='sender']">If there are processing units in the AuditInformation, one must have the role of sender</assert>
			<assert id="3000-002" test="*[@Role='receiver']">If there are processing units in the AuditInformation, one must have the role of receiver</assert>
		</rule>
		<rule context="eml:EML">
			<assert id="3000-004" test="@Id='330'">The value of the Id attribute of the EML element is incorrect</assert>
			<assert id="3000-005" test="eml:ElectionList">The message type must match the Id attribute of the EML element</assert>
		</rule>
	</pattern>
	
	<pattern name="split">
		<rule context="eml:EML[eml:SequenceNumber]">
			<assert id="3000-006" test="eml:SequencedElementName='VoterDetails'">The sequenced element name is incorrect</assert>
		</rule>
	</pattern>

	<pattern name="eml-ukcore">
		<rule context="eml:EML">
			<assert id="4000-001" test="eml:Seal">A Seal must be present</assert>
		</rule>
		<rule context="eml:OtherSeal">
			<assert id="4000-003" test="@Type='RFC2630' or @Type='RFC3161'">If a seal is of type OtherSeal, the Type attribute must have a value of RFC2630 or RFC3161</assert>
		</rule>
		<rule context="eml:Contact">
			<assert id="4000-004" test="*">There must be at least one child of a Contact element</assert>
		</rule>
		<rule context="eml:VoterContact">
			<assert id="4000-005" test="*">There must be at least one child of a VoterContact element</assert>
		</rule>
	</pattern>
	
	<pattern name="eml-330">
		<rule context="eml:VoterDetails">
			<report id="3330-002" test="eml:VoterRegistration/eml:Voter/eml:VoterInformation/eml:PollingDistrict and eml:Election/eml:PollingDistrict">The polling district can only be included for either the voter or the election</report>
			<report id="3330-003" test="eml:VoterRegistration/eml:Voter/eml:VoterInformation/eml:PollingPlace and eml:Election/eml:PollingPlace">The polling place can only be included for either the voter or the election</report>
		</rule>
	</pattern>
	
	<pattern name="eml-330-ukcore">
		<rule context="eml:VoterIdentification">
			<assert id="4330-001" test="eml:VoterName">VoterName must be present</assert>
			<report id="4330-002" test="not(../eml:VoterInformation/eml:Qualifier='OE') and not(eml:ElectoralAddress)">Unless an "other elector", the voter must have an electoral address</report>

			<assert id="4330-003" test="eml:Id/@Type='electoral roll number'">The Id element of Voter must be present and have the Type "electoral roll number"</assert>
			<report id="4330-004" test="../eml:VoterInformation/eml:Qualifier='OE' and eml:ElectoralAddress">An "other elector" must not have an electoral address</report>
		</rule>
		<rule context="eml:VoterDetails">
			<assert id="4330-011" test="eml:Election">VoterDetails must have at least one Election child</assert>
		</rule>
		<rule context="eml:VoterDetails/eml:Election">
			<assert id="4330-012" test="eml:ElectionIdentifier">ElectionIdentifier must be present</assert>
			<assert id="4330-013" test="eml:ContestIdentifier">ContestIdentifier must be present</assert>
			<assert id="4330-014" test="eml:PollingDistrict">PollingDistrict must be present</assert>
		</rule>
		<rule context="eml:Blocked[.='yes']">
			<assert id="3330-015" test="@Reason">The reason attribute is mandatory if Blocked='yes'</assert>
		</rule>
		<rule context="eml:Voter">
			<report id="4330-101" test="eml:VoterInformation/eml:Affiliation">Affiliation is not used</report>
			<report id="4330-102" test="eml:VoterInformation/eml:PlaceOfBirth">PlaceOfBirth is not used</report>
			<report id="4330-103" test="eml:VoterInformation/eml:Eligibility">Eligibility is not used</report>
			<report id="4330-104" test="eml:VoterInformation/eml:Gender">Gender is not used</report>
			<report id="4330-105" test="eml:VoterInformation/eml:Nationality">Nationality is not used</report>
			<report id="4330-106" test="eml:VoterInformation/eml:Ethnicity">Ethnicity is not used</report>
		</rule>
		<rule context="eml:VoterInformation/eml:Qualifier">
			<report id="4330-107" test="not(.='A'  or .='L' or .='U' or .='F' or .='E' or .='G' or .='K' or .='Y' or .='OE' or .='overseas')">The eml:Qualifier may only have the values "A", "L", "U", "F", "E", "G", "K", "Y", "OE", or "overseas"</report>
		</rule>
		<rule context="eml:VoterInformation">
			<report id="4330-108" test="(eml:Qualifier='L' and (eml:Qualifier='U' or eml:Qualifier='F' or eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' )) or 
																	(eml:Qualifier='U' and (eml:Qualifier='F' or eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='F' and (eml:Qualifier='E' or eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='E' and (eml:Qualifier='G' or eml:Qualifier='K' ))  or 
																	(eml:Qualifier='G' and eml:Qualifier='K' )">The Qualifiers "L", "U", "F", "E", "G" and "K" are mutually exclusive</report>
			<report id="4330-109" test="eml:Qualifier='Y' and (eml:Qualifier='L' or eml:Qualifier='U' or eml:Qualifier='F' or eml:Qualifier='E')">The Qualifier "Y" must not appear with the Qualifier "L", "U", "F" or "E"</report>
			<report id="4330-110" test="eml:Qualifier='Y' and not(eml:Qualifier='G' or eml:Qualifier='K')">The Qualifier "Y" must appear with the Qualifier "G" or "K"</report>
		</rule>
	</pattern>
</schema>
